#
# spec file for package lxdm
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _dminitdir %{_prefix}/lib/X11/displaymanagers

Name:           lxdm
Summary:        LXDE Display Manager
License:        GPL-2.0 and LGPL-2.0
Group:          System/GUI/LXDE
Version:        0.4.1
Release:        5.18
Url:            http://lxde.org/
Source0:        %name-%version.tar.bz2
Source1:        README.SUSE
Source2:        %{name}.pamd
Source3:        lxdm-config.desktop
Source4:        config-users.png
Source5:        lxdm
Source6:        sysconfig.lxdm
# PATCH-FEATURE-OPENSUSE lxdm-0.4.0-use-sysconfig.patch andrea@opensuse.org
# this patch allow lxdm to read system settings from /etc/sysconfig
Patch1:         %{name}-0.4.0-use-sysconfig.patch
Patch2:         %{name}-0.4.0-gnome-start.patch
# PATCH-FIX-OPENSUSE lxdm-0.4.0-common.patch werner@novell.com
# this patch fix bnc#586555 lxdm now use common scripts in /etc/X11/xdm
Patch3:         %{name}-0.4.0-common.patch
Patch4:         %{name}-0.4.0-fix-null-pointer-dereference.patch
# Patch needed to use current new default wallpaper location
# bnc#732671
Patch5:         %{name}-0.4.1-background-12.1.patch
Patch6:         %{name}-bnc-741454-d4e41ec.patch
Patch7:         %{name}-0.4.1-fix-gtk2-keyboard-list-empty.patch
Patch8:         %{name}-0.4.1-fix-small-bug-in-theme.patch
# PATCH-FIX-UPSTREAM lxdm-0.4.1-automake-1.14.patch dimstar@opensuse.org -- Backport automake 1.14 fix from git to 0.4.1
Patch9:         %{name}-0.4.1-automake-1.14.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  ConsoleKit-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gettext-runtime
BuildRequires:  gettext-tools
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  iso-codes-devel
BuildRequires:  make
BuildRequires:  pam-devel
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
Requires:       desktop-data-openSUSE
Requires:       pam
PreReq:         %fillup_prereq
Recommends:     gnome-control-center-user-faces
Provides:       lxdm-conf = %version
Obsoletes:      lxdm-conf < %version
%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif

%description
LXDM is the future display manager of LXDE, the Lightweight X11 Desktop
environment. It is designed as a lightweight alternative to replace GDM or
KDM in LXDE distros.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1

%__cp %{SOURCE1} .

%build
intltoolize -f
autoreconf -fi
%configure
%__make %{?jobs:-j%{jobs}}

%install
%makeinstall
%__mkdir_p %buildroot/%_bindir
%__mkdir_p %buildroot/%_datadir/applications
install %SOURCE3 %buildroot/%_datadir/applications/
#need by post checks
%__mkdir_p %buildroot/%_datadir/pixmaps
install %SOURCE4 %buildroot/%_datadir/pixmaps

%suse_update_desktop_file lxdm-config
%__rm %buildroot/%_sbindir/%name
%__rm -rf %buildroot/%_sysconfdir/pam.d/%name
install %SOURCE2 %buildroot/%_sysconfdir/pam.d/%name
chmod -x %buildroot/%_sysconfdir/pam.d/%name
ln -sf %_sbindir/%name-binary %buildroot/%_bindir/%name
%find_lang %name
%__mkdir_p %buildroot/%_rundir
%__mkdir_p %buildroot/%_localstatedir/lib/%name
touch %buildroot/%_rundir/%name.pid
%__mkdir_p %{buildroot}%{_dminitdir}/
%__cp %{SOURCE5} %{buildroot}%{_dminitdir}/
%__mkdir -p %{buildroot}%{_localstatedir}/adm/fillup-templates
cp %{SOURCE6} %{buildroot}%{_localstatedir}/adm/fillup-templates/

%fdupes -s  %buildroot/%_datadir

%pre
/usr/sbin/groupadd -r lxdm 2> /dev/null || :
/usr/sbin/useradd -r -g lxdm -s /bin/false \
-c "LXDE Display Manager daemon" -d /var/lib/lxdm lxdm 2> /dev/null || :
/usr/sbin/usermod -g lxdm -G lxdm -s /bin/false lxdm 2> /dev/null

# this is only needed on initial upgrades becuase of the "noreplace"
# option into files section

%post
chmod 640 %_sysconfdir/%name/%name.conf
chown lxdm:lxdm %_sysconfdir/%name/%name.conf
%{fillup_only -ns displaymanager lxdm}

%files -f %name.lang
%defattr (-,root,root,-)
%doc AUTHORS README COPYING README.SUSE
%dir %{_datadir}/%{name}/
%{_datadir}/applications/lxdm-config.desktop
%{_datadir}/%{name}/*
%dir %{_sysconfdir}/%{name}/
%dir %{_dminitdir}/
%{_bindir}/%{name}
%{_bindir}/%{name}-config
%{_sbindir}/%{name}-binary
%{_libexecdir}/%{name}-greeter-gtk
%{_libexecdir}/%{name}-greeter-gdk
%{_libexecdir}/%{name}-numlock
%config(noreplace) %{_sysconfdir}/%{name}/Xsession
%config(noreplace) %{_sysconfdir}/%{name}/PreReboot
%config(noreplace) %{_sysconfdir}/%{name}/PreShutdown
%config(noreplace) %{_sysconfdir}/%{name}/PreLogin
%config(noreplace) %{_sysconfdir}/%{name}/PostLogin
%config(noreplace) %{_sysconfdir}/%{name}/PostLogout
%config(noreplace) %{_sysconfdir}/%{name}/LoginReady
%attr(640,lxdm,lxdm) %config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%attr(750,lxdm,lxdm) %dir %{_localstatedir}/lib/%{name}
%ghost %_rundir/%{name}.pid
%exclude /%_datadir/pixmaps
%{_dminitdir}/lxdm
%config %{_localstatedir}/adm/fillup-templates/sysconfig.lxdm

%changelog
* Thu Jan 14 2016 dimstar@opensuse.org
- Run intltoolize in order to get valid Makefiles for translation
  installations.
* Thu Nov 20 2014 dimstar@opensuse.org
- Add lxdm-0.4.1-automake-1.14.patch: Fix bootstrapping with
  automake 1.14.
* Wed Sep  3 2014 trcs@gmx.com
- Downgrade to version 0.4.1
  * version 0.5.0 breaks first boot after installation of 13.2
  * rolled back the following patches
  lxdm-0.4.1-fix-small-bug-in-theme.patch
  lxdm-0.4.0-gnome-start.patch
  lxdm-0.5.0-use-openSUSE-background.patch
  lxdm-bnc-741454-d4e41ec.patch
  lxdm-0.4.0-common.patch
  lxdm-0.5.0-use-sysconfig.patch
  lxdm-0.4.1-fix-gtk2-keyboard-list-empty.patch
  lxdm-0.5.0-common.patch
  lxdm-0.4.0-fix-null-pointer-dereference.patch
  lxdm-0.5.0-gnome-start.patch
  lxdm-0.4.0-use-sysconfig.patch
  lxdm-0.4.1-background-12.1.patch
* Mon Jul  7 2014 trcs@gmx.com
- New upstream version 0.5.0
  * fix sometimes we can't logout
  * fix env not passed to session process
  * fix build without pam
  * fix a dup socket call
  * fix auto login with __default__ session
  * fix a potential pid leak, fix user switch vt
  * fix auto login with no password
  * fix a fd leak
  * fix an automake error
  * fix background can't custom in gtk3-3.9.2
  * fix in latest gtk3 default theme background image not stretched
  * fix gtk2 keyboard list empty
  * fix a bug caused by gtk-3.4.3
  * add oop pam support
  * add PAM_XAUDATA support
  * add missing lxcommon.h
  * add config option for ConsoleKit
  * add gnome-shell user switch support
  * add systemd login service support
  * add hack to work with some bad pam module
  * remove consolekit support in Xsession script
  * remove userlist gtk3 limit
  * remove not needed X11 include
  * pam subdirectory should not be installed if --without-pam is set
  * simplify env code by use glib 2.32
  * set active vt before start xserver
  * let lxdm can be compiled on xstreamos
  * measure xserver start time in log
  * configure-check-only-for-ck-connector-in-case-consol
  * support show more than 3 users when gtk3
  * make systemd support configurable
  * enhancements for quick autologin
  * only list user with valid shell
  * try to fix crash when pam return too many env
  * respect display id in server arg
  * translation updates
  * some minor fixes
- Removed unnecessary patches
  * lxdm-0.4.0-fix-null-pointer-dereference.patch
  * lxdm-0.4.1-fix-gtk2-keyboard-list-empty.patch
  * lxdm-0.4.1-fix-small-bug-in-theme.patch
  * lxdm-bnc-741454-d4e41ec.patch
- Renamed remaining patches
  * lxdm-0.4.0-gnome-start.patch
  * lxdm-0.5.0-use-openSUSE-background.patch
  * lxdm-0.4.0-common.patch
  * lxdm-0.5.0-use-sysconfig.patch
  * lxdm-0.5.0-common.patch
  * lxdm-0.4.1-background-12.1.patch
  * lxdm-0.5.0-gnome-start.patch
  * lxdm-0.4.0-use-sysconfig.patch
* Fri May  9 2014 trcs@gmx.com
- Fix build failure produced by Request 233253
* Fri May  9 2014 aj@suse.com
- Use %%_rundir instead of /var/run.
* Fri Apr 18 2014 trcs@gmx.com
- added lxdm-0.4.1-fix-gtk2-keyboard-list-empty.patch
- added lxdm-0.4.1-fix-small-bug-in-theme.patch
  * "prompt" color in Industrial theme gtkrc file is honored
- modified lxdm-0.4.1-background-12.1.patch
  * 1920x1080 is 16:9, the most common aspect ratio for monitors
- removed checks and patches for discontinued versions
  * lxdm-0.4.0-background.patch
  * cleaned spec file
* Fri Jan 11 2013 coolo@suse.com
- run fdupes only as last step, or it will create symlinks to files
  deleted later
* Tue Nov 20 2012 dimstar@opensuse.org
- Fix useradd invocation: -o is useless without -u and newer
  versions of pwdutils/shadowutils fail on this now.
* Thu Sep  6 2012 toganm@opensuse.org
- added sysconfig.lxdm fillup template bnc#766762
* Wed Jul 18 2012 bwiedemann@suse.com
- do not busy-poll forever (bnc#741454)
* Thu Jun  7 2012 pgajdos@suse.com
- use autoreconf because of suse-sysconfig.h & co.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Dec  5 2011 lthuns@opensuse.org
- added patch to use new default wallpaper location since OS 12.1
  bnc#732671
* Wed Sep 21 2011 eich@suse.com
- Don't use %%{_libexecdir} for init script path, it's not uniformly
  defined on all supported products.
* Tue Sep 20 2011 eich@suse.com
- Change %%{_libdir} to ${_libexecdir}.
* Mon Sep  5 2011 eich@suse.com
- Add %%_libdir/X11 to the list of dirs.
* Wed Aug 31 2011 eich@suse.com
- %%{_libdir}/X11/displaymanagers is no config file.
* Wed Aug 31 2011 eich@suse.com
- lxdm: fixed bug.
* Tue Aug 30 2011 eich@suse.com
- Changed %%{_sysconfdir}/X11/displaymanagers to
  %%{_libdir}/X11/displaymanagers.
* Tue Aug 30 2011 eich@suse.com
- add missing "%%dir %%{_sysconfdir}/X11/displaymanagers"
  to specfile.
* Thu Aug 25 2011 eich@novell.com
- lxdm: Add startup script file to be sourced by /etc/xinit.d/xdm.
  The display manager stratup script /etc/init.d/xdm should not
  contain any code specific to a display manager. Instead such code
  should live in a script file supplied by the specific dm which
  is sourced by the start script. Those script files will live
  in /etc/X11/displaymanagers/.
* Fri Aug 12 2011 andrea@opensuse.org
- recommends user faces for suse >= 12.1
* Mon Aug  1 2011 andrea@opensuse.org
- added desktop file for lxdm-config
* Fri Jul 29 2011 andrea@opensuse.org
- new upstream version 0.4.1
  * translations updates
  * fix lost data entry when install
* Fri Jul 29 2011 gber@opensuse.org
- added lxdm-0.4.0-fix-null-pointer-dereference.patch in order to
  fix a potential NUll pointer dereference
* Thu Jul 28 2011 andrea@opensuse.org
- improved lxdm-0.4.0-use-sysconfig.patch to allow lxdm-config
  to support suse specific sysconfig.
* Thu Jul 21 2011 andrea@opensuse.org
- new upstream version 0.4.0
  * added lxdm-config
  * added gtk3 support
  * many improvments
- rebased all patches
- removed lxdm-conf recommendation since a config tool
  is provided by lxdm itself
* Thu Sep 30 2010 andrea@opensuse.org
- New upstream version 0.3.0
  * Translations improvments
  * fixed bugs in auth view
  * fix a language list issue
  * UI improvments (with user lists available)
* Fri Aug 13 2010 andrea@opensuse.org
- fixed package version (sync with 11.3 updates)
- added lxdm-0.2.97-fix-bnc630862.patch to allow lxdm to login
  even if the password contains spaces
- added post script to allow successful upgrade from suse 11.3
  without updates repo bnc#629728
* Tue Aug  3 2010 andrea@opensuse.org
- lxdm-greeters now are executed as non-root user
* Sat Jul 31 2010 andrea@opensuse.org
- new git version 20100730
  * try to low the user
  * move write config from greeter to lxdm-binary
* Thu Jul 29 2010 andrea@opensuse.org
- new git version 20100729
* Tue Jul 20 2010 andrea@opensuse.org
- new git version 20100721
- removed lxdm-0.3.0-fix-script-environment.patch and
  lxdm-0.3.0-logging.patch now into upstream code
* Tue Jul 13 2010 guido+opensuse.org@berhoerster.name
- fix logging patch
* Thu Jul  8 2010 guido+opensuse.org@berhoerster.name
- update to current development version
  + less boken signal handling
  + multiuser support
* Tue Jun  8 2010 andrea@opensuse.org
- changed RPM Group to System/GUI/LXDE
* Sat May 22 2010 guido+opensuse.org@berhoerster.name
- use glib logging and redirect stderr/stdout to logfile when in
  daemon mode
* Sat May 22 2010 andrea@opensuse.org
- fixed patch tag
* Fri May 21 2010 guido+opensuse.org@berhoerster.name
- added a patch to remove the on_session_exit callback in the
  signal handler before trying to kill the session, addresses
  bnc#584573
* Wed May 19 2010 guido+opensuse.org@berhoerster.name
- added patch tag
- added patch to set up the environment for the login/logout
  scripts
* Tue May 18 2010 guido+opensuse.org@berhoerster.name
- fixed call to /etc/X11/xdm/Xsession from /etc/lxdm/Xsession which
  was missing an argument preventing the selection of alternative
  sessions
* Fri May 14 2010 guido+opensuse.org@berhoerster.name
- fixed broken patch
* Fri Apr 30 2010 andrea@opensuse.org
- new upstream version 0.2.0
- removed lxdm-disable-password-security-hole.patch
- added lxdm-0.2.0-gnome-start.patch to start gnome properly
- add version to all other patches
- spec file clean up
* Sun Apr  4 2010 andrea@opensuse.org
- removed no more useful patches
- fixed bnc#580043
- added lxdm-disable-password-security-hole.patch to disable
  clear password into lxdm conf file
* Sun Apr  4 2010 andrea@opensuse.org
- other pam improvments
* Thu Apr  1 2010 andrea@opensuse.org
- improved pam support
* Wed Mar 31 2010 andrea@opensuse.org
- don't set the display-device at ck session just follow the gdm
- use the libXau instead of run xauth, may faster
- make lxdm load lang list a little fast
- initial changes to remove iso_codes
* Thu Mar 18 2010 andrea@opensuse.org
- fixed missin exec bit to lxdm scripts
* Wed Mar 17 2010 andrea@opensuse.org
- added lxdm-common.patch to fix bnc#586555
* Wed Mar 17 2010 andrea@opensuse.org
- restored lxdm-stderr_stdout_log.patch, it wasn't really fixed
* Sat Mar 13 2010 andrea@opensuse.org
- add PreShutdown and PreRebot support
* Fri Mar 12 2010 andrea@opensuse.org
- new git version 2010 03 12
- add PostLogin,PreLogin,LoginReady,PostLogout steps support
- removed lxdm-stderr_stdout_log.patch, fixed upstream
* Mon Mar  1 2010 andrea@opensuse.org
- fixed patches, now apply without fuzzy
* Thu Feb 25 2010 andrea@opensuse.org
- enhance get_lock
- use /var/run/lxdm/lxdm.auth default
- use /dev/console instead of /dev/tty0
* Fri Feb 12 2010 andrea@opensuse.org
- added lxdm-stderr_stdout_log.patch to log into /var/log/lxdm
  all lxdm messages that was showed into tty1
* Thu Feb 11 2010 andrea@opensuse.org
- removed patches now into upstream code: lxdm-Xsession.patch
  and lxdm-libexec.patch
- lxde moved to git, change version according to it
* Tue Feb  9 2010 andrea@opensuse.org
- removed lxdmconf, it's now a separeted package
* Sat Feb  6 2010 andrea@opensuse.org
- added lxdmconf configuration tool
* Thu Feb  4 2010 andrea@opensuse.org
- fixed libexecdir path
* Wed Feb  3 2010 andrea@opensuse.org
- new svn version 0.2.0svn2326 that adds theming support and
  several bugfix and new features like theme support
- removed "lxdm-0.1.0-switch-to-old-tty.patch"
- all patched ported to apply on new changes
* Sun Jan 24 2010 andrea@opensuse.org
- backported from lxdm trunk "lxdm-0.1.0-switch-to-old-tty.patch"
  to see bootsplash on shutdown
- removed version macros from patch list as packaging standard
* Tue Jan 12 2010 andrea@opensuse.org
- new upstream version 0.1.0
- Change license to GPLv2+ and LGPLv2+
- spec file fix
- renamed patches to respect name-version standard
* Tue Dec 29 2009 andrea@opensuse.org
- added sysconfig patch and README.SUSE
  now LXDM reads autologin users and
  default session from system sysconfig files
* Sat Dec 26 2009 andrea@opensuse.org
- new svn version, with several code fix
* Sat Dec  5 2009 andrea@opensuse.org
- fixed ISO-CODES path
* Wed Dec  2 2009 prusnak@suse.cz
- cleanup spec
* Sun Nov  8 2009 andrea@opensuse.org
- new svn version 2140
* Mon Oct 26 2009 andrea@opensuse.org
- new svn version svn2091
  - bugfixes and german translation
* Sat Oct 24 2009 andrea@opensuse.org
- removed italian and gcc patch (accepted upstream)
- fixed a crasch on suse 11.2
* Thu Oct 22 2009 andrea@opensuse.org
- working on branding
* Thu Oct 22 2009 andrea@opensuse.org
- fixed linking errors (because of "--as-needed")
* Thu Oct 22 2009 andrea@opensuse.org
- added pam patch
- added gcc-warn patch
- added italian translation
* Wed Oct 21 2009 andrea@opensuse.org
- new svn version 2083 (added pam support and first translations)
* Wed Sep 30 2009 andrea@opensuse.org
- new svn version 2050
* Thu Sep 17 2009 andrea@opensuse.org
- new svn version (lots of improvments)
* Fri Sep 11 2009 andrea@opensuse.org
- new package
